@@ -1,6 +1,8 @@
 test_that("overlap_circle", {
   skip_if_not_installed("VennDiagram")
 
+  .old_wd <- setwd(tempdir())
+
   # Saving to file (PDF or PNG)
   x1 <- overlap_circle(3.5)
   ggplot2::ggsave(x1,
@@ -18,9 +20,6 @@ test_that("overlap_circle", {
   # expect_snapshot_file("plot.jpg")
   # Not working...
 
-  # Remove file
-  unlink("plot.jpg")
-
   # Score of 1 (0% overlap)
   x2 <- overlap_circle(1)
 
@@ -41,4 +40,10 @@ test_that("overlap_circle", {
 
   expect_s3_class(x5, "gList")
 
+  # Remove files
+  unlink("plot.jpg")
+  unlink("Rplots.pdf")
+
+  setwd(.old_wd)
+
 })
